package com.livelike.flutter.livelike_flutter_sdk

import android.content.Context
import android.util.Log
import android.view.View
import com.livelike.engagementsdk.chat.ChatView
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.StandardMessageCodec
import io.flutter.plugin.platform.PlatformView
import io.flutter.plugin.platform.PlatformViewFactory

class ChatViewFactory(
    private val plugin: LivelikeFlutterSdkPlugin,
    private val messenger: BinaryMessenger
) : PlatformViewFactory(StandardMessageCodec.INSTANCE) {
    override fun create(context: Context?, viewId: Int, args: Any?): PlatformView {
        val creationParams = args as Map<String?, Any?>?
        return PluginChatView(context, plugin, viewId, creationParams, messenger)
    }
}

class PluginChatView(
    context: Context?,
    var plugin: LivelikeFlutterSdkPlugin,
    viewId: Int,
    creationParams: Map<String?, Any?>?,
    messenger: BinaryMessenger
) : PlatformView, MethodChannel.MethodCallHandler {
    private var chatView: ChatView
    private val methodChannel: MethodChannel = MethodChannel(messenger, "chatView$viewId")

    init {
        methodChannel.setMethodCallHandler(this)
        chatView = ChatView(context!!, null)
    }

    override fun getView(): View {
        return chatView
    }

    override fun dispose() {

    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        Log.d("LivelikeSDK", "Method Call: ${call.method}")
        when (call.method) {
            "setSession" -> {
                val chatRoomId = call.argument<String>("chatRoomId") as String
                plugin.chatSessionMap[chatRoomId]?.let {
                    chatView.setSession(it)
                    result.success(null)
                    return
                }
                result.error("", "Chat Session not found", null)
            }
        }
    }
}