import 'package:chewie/chewie.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:livelike_flutter_sdk/livelike_flutter_sdk.dart';
import 'package:livelike_flutter_sdk_example/home.dart';
import 'package:video_player/video_player.dart';

class AllFeaturesScreen extends StatelessWidget {
  final controller = Get.put(AllFeaturesController());

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        child: Column(
          children: [
            Expanded(
              child: Obx(() => controller.videoInitialized.value
                  ? Stack(
                      children: [
                        Positioned.fill(
                          child:
                              Chewie(controller: controller.chewieController),
                        ),
                        Positioned(
                          left: 0,
                          top: 0,
                          height: 30,
                          width: 30,
                          child: IconButton(
                            color: Colors.blueAccent,
                            icon: Icon(
                              Icons.cancel_outlined,
                              size: 25,
                              color: Colors.black,
                            ),
                            onPressed: () {
                              Get.back();
                            },
                          ),
                        ),
                      ],
                    )
                  : SizedBox.shrink()),
            ),
            Expanded(
              child: Stack(
                children: [
                  Positioned.fill(
                    child: Obx(() => controller.session.value != null
                        ? ChatView(
                            session: controller.session.value!.chatSession!)
                        : Container()),
                  ),
                  Obx(() => controller.session.value != null
                      ? Padding(
                          padding: const EdgeInsets.all(8),
                          child: WidgetView(session: controller.session.value!),
                        )
                      : SizedBox.shrink()),
                ],
              ),
              flex: 3,
            )
          ],
        ),
      ),
    );
  }
}

class AllFeaturesController extends GetxController {
  final Rx<Session?> session = Rx(null);
  late ChewieController chewieController;
  final videoInitialized = false.obs;

  late void Function() listener;

  @override
  void onInit() async {
    super.onInit();
    final sdk = Get.find<EngagementSDK>();
    final Channel channel = Get.arguments;

    //Video PLayer
    listener = () {
      print("object>>>${chewieController.videoPlayerController.value.position.inMicroseconds}");
      session.value?.setVideoPDTTime(
          chewieController.videoPlayerController.value.position.inMicroseconds);
    };
    videoInitialized.value = false;
    final videoController = VideoPlayerController.network(channel.stream_url!);
    chewieController = ChewieController(
        videoPlayerController: videoController,
        autoPlay: true,
        looping: false,
        isLive: false,
        aspectRatio: 16 / 9,
        autoInitialize: true,
        showControls: true);
    videoInitialized.value = true;
    //Video PLayer

    // Session
    session.value = await sdk.createSession(channel.id!);
    session.value?.widgetStream.listen((event) async {
      Get.log("object>>${event.timeout_time} => ${event.timeout}");
    }).onError((error) {
      Get.log("Error: $error");
    });
    chewieController.videoPlayerController.addListener(listener);
  }

  @override
  void dispose() {
    super.dispose();
    chewieController.pause();
    chewieController.videoPlayerController.removeListener(listener);
    chewieController.dispose();
    session.value?.close();
  }

  void playPauseVideo() {
    if (chewieController.isPlaying) {
      chewieController.pause();
    } else {
      chewieController.play();
    }
  }
}
