import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:livelike_flutter_sdk/livelike_flutter_sdk.dart';
import 'package:livelike_flutter_sdk_example/app_widgets.dart';

import 'home.dart';

class ChatOnlyScreen extends StatelessWidget {
  final controller = Get.put(ChatOnlyController());

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(),
      body: Padding(
        padding: const EdgeInsets.only(),
        child: Column(
          children: [
            Obx(() => controller.channel.value == null
                ? Row(
                    children: [
                      Expanded(
                        child: AppTextField(
                          hintText: '',
                          floatingHintText: 'Enter Chat Room Id',
                          onChanged: (s) {
                            controller.chatRoomId.value = s;
                          },
                          minLines: 1,
                          maxLines: 1,
                          enabled: controller.chatSession.value == null,
                          text: controller.chatRoomId.value,
                        ),
                      ),
                      controller.createLoading.value
                          ? SizedBox(
                              child: CircularProgressIndicator(
                                strokeWidth: 1.5,
                              ),
                              width: 15,
                              height: 15)
                          : IconButton(
                              onPressed: () {
                                if (controller.chatSession.value == null) {
                                  controller.createChatSession();
                                } else {
                                  controller.chatSession.value = null;
                                  controller.chatRoomId.value = null;
                                }
                              },
                              icon: Icon(controller.chatSession.value == null
                                  ? Icons.send
                                  : Icons.delete),
                            )
                    ],
                  )
                : SizedBox.shrink()),
            Expanded(
              child: Obx(() => controller.chatSession.value != null
                  ? ChatView(
                      key: Key("${controller.chatSession.value!.chatRoomId}"),
                      session: controller.chatSession.value!,
                    )
                  : SizedBox.shrink()),
            ),
          ],
        ),
      ),
    );
  }
}

class ChatOnlyController extends GetxController {
  final Rx<ChatSession?> chatSession = Rx(null);
  final Rx<Channel?> channel = Rx(null);
  final sdk = Get.find<EngagementSDK>();
  final Rx<String?> chatRoomId = Rx(null);
  final createLoading = false.obs;

  @override
  void onInit() async {
    super.onInit();
    channel.value = Get.arguments;
    if (channel.value != null) {
      chatSession.value =
          (await sdk.createSession(channel.value!.id!)).chatSession;
    }
  }

  void createChatSession() async {
    final id = chatRoomId.value;
    if (id != null && id.isNotEmpty) {
      createLoading.value = true;
      chatSession.value = await sdk.createChatSession(id);
      createLoading.value = false;
    } else {
      showErrorMessage("Please Enter Valid ChatRoom ID");
    }
  }
}
