import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:livelike_flutter_sdk/src/constants.dart';
import 'package:livelike_flutter_sdk/src/session.dart';

class ChatView extends StatelessWidget {
  final Map<String, dynamic> creationParams = <String, dynamic>{};
  final ChatSession session;

  ChatView({Key? key, required this.session}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Platform.isAndroid
        ? PlatformViewLink(
            key: Key("platform-view-${session.chatRoomId}"),
            surfaceFactory: (context, controller) {
              return AndroidViewSurface(
                controller: controller as AndroidViewController,
                gestureRecognizers: const <
                    Factory<OneSequenceGestureRecognizer>>{},
                hitTestBehavior: PlatformViewHitTestBehavior.opaque,
              );
            },
            onCreatePlatformView: (params) {
              return PlatformViewsService.initSurfaceAndroidView(
                id: params.id,
                viewType: chatViewType,
                layoutDirection: TextDirection.ltr,
                creationParams: creationParams,
                creationParamsCodec: const StandardMessageCodec(),
              )
                ..addOnPlatformViewCreatedListener((id) async {
                  final _channel = new MethodChannel('$chatViewType$id');
                  _channel.invokeMethod(
                      setSessionKey, {chatRoomIdKey: session.chatRoomId});
                  params.onPlatformViewCreated(id);
                })
                ..create();
            },
            viewType: chatViewType)
        : Platform.isIOS
            ? UiKitView(
                key: Key("platform-view-${session.chatRoomId}"),
                viewType: chatViewType,
                layoutDirection: TextDirection.ltr,
                creationParams: creationParams,
                creationParamsCodec: const StandardMessageCodec(),
                onPlatformViewCreated: (id) {
                  final _channel = new MethodChannel('$chatViewType$id');
                  _channel.invokeMethod(
                      setSessionKey, {chatRoomIdKey: session.chatRoomId});
                },
              )
            : Container(
                alignment: Alignment.center,
                child: Text("Platform Not Supported"),
              );
  }
}
