import 'package:livelike_flutter_sdk/src/constants.dart';
import 'package:livelike_flutter_sdk/src/model/livelike_widget.dart';

class Session extends BaseSession {
  final String? programId;
  ChatSession? chatSession;

  Stream<LiveLikeWidget> get widgetStream =>
      widgetStreamChannel.receiveBroadcastStream().map((event) =>
          LiveLikeWidget.fromJson(event["data"] ?? {})..show = event["show"]);

  Session(this.programId, String? chatRoomId) : super(programId) {
    chatSession = ChatSession(chatRoomId);
  }

  @override
  Future<void> pause() {
    return livelike_method_channel
        .invokeMethod(pauseSessionKey, {programIDKey: programId});
  }

  @override
  Future<void> resume() {
    return livelike_method_channel
        .invokeMethod(resumeSessionKey, {programIDKey: programId});
  }

  @override
  Future<void> close() {
    return livelike_method_channel
        .invokeMethod(closeSessionKey, {programIDKey: programId});
  }
}

class ChatSession extends BaseSession {
  final String? chatRoomId;

  ChatSession(this.chatRoomId) : super(chatRoomId);

  @override
  Future<void> close() {
    return livelike_method_channel
        .invokeMethod(closeSessionKey, {chatRoomIdKey: chatRoomId});
  }

  @override
  Future<void> pause() {
    return livelike_method_channel
        .invokeMethod(pauseChatSessionKey, {chatRoomIdKey: chatRoomId});
  }

  @override
  Future<void> resume() {
    return livelike_method_channel
        .invokeMethod(resumeChatSessionKey, {chatRoomIdKey: chatRoomId});
  }
}

abstract class BaseSession {
  String? id;

  BaseSession(this.id);

  Future<void> setVideoPDTTime(int time) {
    return livelike_method_channel.invokeMethod(setVideoTimePDTKey, {
      ((this is ChatSession) ? chatRoomIdKey : programIDKey): id,
      videoTimePDTKey: time,
    });
  }

  Future<void> resume();

  Future<void> pause();

  Future<void> close();
}
