import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:livelike_flutter_sdk/src/constants.dart';
import 'package:livelike_flutter_sdk/src/session.dart';

class WidgetView extends StatefulWidget {
  WidgetView({Key? key, required this.session, this.widgetHeight = 320})
      : super(key: key);
  final Session session;
  final double widgetHeight;

  @override
  _WidgetViewState createState() => _WidgetViewState();
}

class _WidgetViewState extends State<WidgetView> {
  final Map<String, dynamic> creationParams = <String, dynamic>{};
  bool _showWidget = true;

  @override
  Widget build(BuildContext context) {
    print("WidgetView: $_showWidget");
    return SizedBox(
      height: _showWidget ? widget.widgetHeight : 0,
      child: Platform.isAndroid
          ? PlatformViewLink(
              key: widget.key,
              surfaceFactory: (context, controller) {
                return AndroidViewSurface(
                  controller: controller as AndroidViewController,
                  gestureRecognizers: const <
                      Factory<OneSequenceGestureRecognizer>>{},
                  hitTestBehavior: PlatformViewHitTestBehavior.opaque,
                );
              },
              onCreatePlatformView: (params) {
                return PlatformViewsService.initSurfaceAndroidView(
                  id: params.id,
                  viewType: widgetViewTypeKey,
                  layoutDirection: TextDirection.ltr,
                  creationParams: creationParams,
                  creationParamsCodec: const StandardMessageCodec(),
                )
                  ..addOnPlatformViewCreatedListener((id) async {
                    final _channel = new MethodChannel('$widgetViewTypeKey$id');
                    await _channel.invokeMethod(setSessionKey,
                        {programIDKey: widget.session.programId});
                    params.onPlatformViewCreated(id);
                    streamListener();
                  })
                  ..create();
              },
              viewType: widgetViewTypeKey)
          : Platform.isIOS
              ? UiKitView(
                  key: widget.key,
                  viewType: widgetViewTypeKey,
                  layoutDirection: TextDirection.ltr,
                  creationParams: creationParams,
                  creationParamsCodec: const StandardMessageCodec(),
                  gestureRecognizers: const <
                      Factory<OneSequenceGestureRecognizer>>{},
                  hitTestBehavior: PlatformViewHitTestBehavior.opaque,
                  onPlatformViewCreated: (id) async {
                    final _channel = new MethodChannel('$widgetViewTypeKey$id');
                    await _channel.invokeMethod(setSessionKey,
                        {programIDKey: widget.session.programId});
                    streamListener();
                  },
                )
              : Container(),
    );
  }

  void streamListener() async {
    print("Listener: $_showWidget");
    await Future.delayed(const Duration(seconds: 5));
    if (mounted)
      setState(() {
        _showWidget = false;
      });
    widget.session.widgetStream.listen((event) async {
      if (mounted) {
        print(
            "Widget Id: ${event.id} , timeout: ${event.timeout}, ${event
                .timeout_time}, Show:${event.show}");
        if (event.show == false) await Future.delayed(
            const Duration(seconds: 3));
        setState(() {
          _showWidget = (event.show ?? false);
        });
      }
    });
  }
}
